@@ -1,7 +1,5 @@
 #include "marshal.h"
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,10 +47,73 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* VOID:VOID (marshal.list:1) */
+void
+gl_marshal_VOID__VOID (GClosure     *closure,
+                       GValue       *return_value G_GNUC_UNUSED,
+                       guint         n_param_values,
+                       const GValue *param_values,
+                       gpointer      invocation_hint G_GNUC_UNUSED,
+                       gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__VOID) (gpointer data1,
+                                           gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__VOID callback;
+
+  g_return_if_fail (n_param_values == 1);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__VOID) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            data2);
+}
 
 /* VOID:INT (marshal.list:2) */
+void
+gl_marshal_VOID__INT (GClosure     *closure,
+                      GValue       *return_value G_GNUC_UNUSED,
+                      guint         n_param_values,
+                      const GValue *param_values,
+                      gpointer      invocation_hint G_GNUC_UNUSED,
+                      gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__INT) (gpointer data1,
+                                          gint arg1,
+                                          gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__INT callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__INT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_int (param_values + 1),
+            data2);
+}
 
 /* VOID:INT,INT (marshal.list:3) */
 void
@@ -63,13 +124,13 @@ gl_marshal_VOID__INT_INT (GClosure     *closure,
                           gpointer      invocation_hint G_GNUC_UNUSED,
                           gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
-                                              gint         arg_1,
-                                              gint         arg_2,
-                                              gpointer     data2);
-  GMarshalFunc_VOID__INT_INT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer data1,
+                                              gint arg1,
+                                              gint arg2,
+                                              gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -100,13 +161,13 @@ gl_marshal_VOID__INT_UINT (GClosure     *closure,
                            gpointer      invocation_hint G_GNUC_UNUSED,
                            gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__INT_UINT) (gpointer     data1,
-                                               gint         arg_1,
-                                               guint        arg_2,
-                                               gpointer     data2);
-  GMarshalFunc_VOID__INT_UINT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__INT_UINT) (gpointer data1,
+                                               gint arg1,
+                                               guint arg2,
+                                               gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__INT_UINT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -129,6 +190,39 @@ gl_marshal_VOID__INT_UINT (GClosure     *closure,
 }
 
 /* VOID:DOUBLE (marshal.list:5) */
+void
+gl_marshal_VOID__DOUBLE (GClosure     *closure,
+                         GValue       *return_value G_GNUC_UNUSED,
+                         guint         n_param_values,
+                         const GValue *param_values,
+                         gpointer      invocation_hint G_GNUC_UNUSED,
+                         gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__DOUBLE) (gpointer data1,
+                                             gdouble arg1,
+                                             gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__DOUBLE callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__DOUBLE) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_double (param_values + 1),
+            data2);
+}
 
 /* VOID:DOUBLE,DOUBLE (marshal.list:6) */
 void
@@ -139,13 +233,13 @@ gl_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__DOUBLE_DOUBLE) (gpointer     data1,
-                                                    gdouble      arg_1,
-                                                    gdouble      arg_2,
-                                                    gpointer     data2);
-  GMarshalFunc_VOID__DOUBLE_DOUBLE callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__DOUBLE_DOUBLE) (gpointer data1,
+                                                    gdouble arg1,
+                                                    gdouble arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__DOUBLE_DOUBLE callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -168,8 +262,74 @@ gl_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
 }
 
 /* VOID:OBJECT (marshal.list:7) */
+void
+gl_marshal_VOID__OBJECT (GClosure     *closure,
+                         GValue       *return_value G_GNUC_UNUSED,
+                         guint         n_param_values,
+                         const GValue *param_values,
+                         gpointer      invocation_hint G_GNUC_UNUSED,
+                         gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__OBJECT) (gpointer data1,
+                                             gpointer arg1,
+                                             gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_object (param_values + 1),
+            data2);
+}
 
 /* VOID:STRING (marshal.list:8) */
+void
+gl_marshal_VOID__STRING (GClosure     *closure,
+                         GValue       *return_value G_GNUC_UNUSED,
+                         guint         n_param_values,
+                         const GValue *param_values,
+                         gpointer      invocation_hint G_GNUC_UNUSED,
+                         gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING) (gpointer data1,
+                                             gpointer arg1,
+                                             gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__STRING callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            data2);
+}
 
 /* VOID:UINT,BOOLEAN (marshal.list:9) */
 void
@@ -180,13 +340,13 @@ gl_marshal_VOID__UINT_BOOLEAN (GClosure     *closure,
                                gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_BOOLEAN) (gpointer     data1,
-                                                   guint        arg_1,
-                                                   gboolean     arg_2,
-                                                   gpointer     data2);
-  GMarshalFunc_VOID__UINT_BOOLEAN callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__UINT_BOOLEAN) (gpointer data1,
+                                                   guint arg1,
+                                                   gboolean arg2,
+                                                   gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_BOOLEAN callback;
 
   g_return_if_fail (n_param_values == 3);
 
